==> 0.0.2.tar.gz: lib/core/hub.dart <==
import 'package:bizdoc/services/session.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';

import 'dart:async';
import 'dart:convert';

import 'package:bizdoc/models/contracts.dart';
import 'configuration.dart';
import 'notification.service.dart';

class Hub {
  static final Hub _instance = Hub._internal();
  final _controller = StreamController<ContractBase>.broadcast();

  Stream<ContractBase> get events => _controller.stream;

  void initialize(FirebaseSettings firebaseSettings) async {
    try {
      await Firebase.initializeApp(
          options: FirebaseOptions(
              apiKey: firebaseSettings.apiKey,
              projectId: firebaseSettings.projectId,
              messagingSenderId: firebaseSettings.senderId,
              appId: firebaseSettings.appId));
      FirebaseMessaging.onBackgroundMessage(
          _firebaseMessagingBackgroundHandler);
      FirebaseMessaging.onMessage.listen(_distribute);
      await FirebaseMessaging.instance.requestPermission(
        alert: true,
        announcement: false,
        badge: true,
        carPlay: false,
        criticalAlert: false,
        provisional: false,
        sound: true,
      );
      final token = await FirebaseMessaging.instance.getToken(
        vapidKey: firebaseSettings.vapidKey,
      );
      await session.registerDevice(token!, "Firebase");
    } catch (e) {
      print(e);
    }
    notifications.initialize();
  }

  void _distribute(RemoteMessage message) {
    var data = message.data['model'];
    final contract =
        ContractBase.construct(message.data['type'], jsonDecode(data));
    if (contract != null) _controller.add(contract);
    notifications.notify(contract, data);
  }

  Future<void> _firebaseMessagingBackgroundHandler(
      RemoteMessage message) async {
    var data = message.data['model'];
    final contract =
        ContractBase.construct(message.data['type'], jsonDecode(data));
    await NotificationsService().notify(contract, data);
  }

  Future onDidReceiveLocalNotification(
      int id, String? title, String? body, String? payload) async {}

  factory Hub() {
    return _instance;
  }

  void dispose() {
    _controller.close();
  }

  Hub._internal();
}

final hub = Hub();

==> 0.0.8.tar.gz: lib/core/hub.dart <==
import 'package:bizdoc/services/session.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';

import 'dart:async';
import 'dart:convert';

import 'package:bizdoc/models/contracts.dart';
import 'configuration.dart';
import 'notification.dart';

class Hub {
  static final Hub _instance = Hub._internal();
  final _controller = StreamController<ContractBase>.broadcast();

  Stream<ContractBase> get events => _controller.stream;

  void initialize(FirebaseSettings firebaseSettings) async {
    try {
      await Firebase.initializeApp(
          options: FirebaseOptions(
              apiKey: firebaseSettings.apiKey,
              projectId: firebaseSettings.projectId,
              messagingSenderId: firebaseSettings.senderId,
              appId: firebaseSettings.appId));
      FirebaseMessaging.onBackgroundMessage(
          _firebaseMessagingBackgroundHandler);
      FirebaseMessaging.onMessage.listen(_distribute);
      await FirebaseMessaging.instance.requestPermission(
        alert: true,
        announcement: false,
        badge: true,
        carPlay: false,
        criticalAlert: false,
        provisional: false,
        sound: true,
      );
      final token = await FirebaseMessaging.instance.getToken(
        vapidKey: firebaseSettings.vapidKey,
      );
      await session.registerDevice(token!, "Firebase");
    } catch (e) {
      print(e);
    }
    notifications.initialize();
  }

  void _distribute(RemoteMessage message) {
    var data = message.data['model'];
    final contract =
        ContractBase.construct(message.data['type'], jsonDecode(data));
    if (contract != null) _controller.add(contract);
    notifications.notify(contract, data);
  }

  Future<void> _firebaseMessagingBackgroundHandler(
      RemoteMessage message) async {
    var data = message.data['model'];
    final contract =
        ContractBase.construct(message.data['type'], jsonDecode(data));
    await NotificationsService().notify(contract, data);
  }

  Future onDidReceiveLocalNotification(
      int id, String? title, String? body, String? payload) async {}

  factory Hub() {
    return _instance;
  }

  void dispose() {
    _controller.close();
  }

  Hub._internal();
}

final hub = Hub();
